@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 use Moo;
 use strictures 2;
@@ -15,14 +15,14 @@ use File::Temp qw/ tempfile /;
 
 has database => (
     is        => 'ro',
-    isa       => sub { -e $_[0] },
+    isa       => sub { die 'database does not exist' unless -e $_[0] },
     predicate => 'has_database',
 );
 
 
 has schema => (
     is        => 'ro',
-    isa       => sub { -e $_[0] },
+    isa       => sub { die 'schema does not exist' unless -e $_[0] },
     predicate => 'has_schema',
 );
 
@@ -109,7 +109,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0104
+version 0.0105
 
 =head1 SYNOPSIS
 
@@ -172,7 +172,8 @@ Create a new C<Test::SQLite> object.
 
 =head2 BUILD
 
-Ensure that we are not given both a B<database> and a B<schema>.
+Ensure that we are given either a B<database> or a B<schema> and not
+both.
 
 =head1 THANK YOU
 
